@@ -6,7 +6,7 @@
 ;;         MORIOKA Tomohiko <morioka@jaist.ac.jp>
 ;; Maintainer: MORIOKA Tomohiko <morioka@jaist.ac.jp>
 ;; Created: 1994/08/21 renamed from mime.el
-;; Version: $Revision: 7.108 $
+;; Version: $Revision: 1.6 $
 ;; Keywords: mail, news, MIME, multimedia, multilingual
 
 ;; This file is part of tm (Tools for MIME).
@@ -120,7 +120,7 @@
 ;;;
 
 (defconst mime-editor/RCS-ID
-  "$Id: tm-edit.el,v 7.108 1997/05/27 03:22:55 morioka Exp $")
+  "$Id: tm-edit.el,v 1.6 2000/09/04 06:51:02 martinb Exp $")
 
 (defconst mime-editor/version (get-version-string mime-editor/RCS-ID))
 
@@ -635,7 +635,7 @@ Tspecials means any character that matches with it in header must be quoted.")
 			mime-editor/menu-list)))
 	 )))
 
-;;; modified by Steven L. Baur <steve@miranova.com>
+;;; modified by Steven L. Baur <steve@xemacs.org>
 ;;;	1995/12/6 (c.f. [tm-en:209])
 (if (and running-xemacs (not (boundp 'mime-editor/popup-menu-for-xemacs)))
     (setq mime-editor/popup-menu-for-xemacs
@@ -1385,7 +1385,7 @@ Optional DELIMITER specifies parameter delimiter (';' by default)."
 
 (defun mime-prompt-for-parameter (parameter)
   "Ask for PARAMETER.
-Parameter must be '(PROMPT CHOICE1 (CHOISE2 ...))."
+Parameter must be '(PROMPT CHOICE1 (CHOICE2 ...))."
   (let* ((prompt (car parameter))
 	 (choices (mapcar (function
 			   (lambda (e)
